@@ -19,9 +19,16 @@ package org.apache.maven.plugin.source;
  * under the License.
  */
 
+import java.io.File;
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.List;
+
 import org.apache.maven.archiver.MavenArchiveConfiguration;
 import org.apache.maven.archiver.MavenArchiver;
 import org.apache.maven.artifact.DependencyResolutionRequiredException;
+import org.apache.maven.execution.MavenSession;
 import org.apache.maven.model.Resource;
 import org.apache.maven.plugin.AbstractMojo;
 import org.apache.maven.plugin.MojoExecutionException;
@@ -35,16 +42,10 @@ import org.codehaus.plexus.archiver.jar.JarArchiver;
 import org.codehaus.plexus.archiver.jar.ManifestException;
 import org.codehaus.plexus.util.FileUtils;
 
-import java.io.File;
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.List;
-
 /**
  * Base class for bundling sources into a jar archive.
  *
- * @version $Id: AbstractSourceJarMojo.java 1356885 2012-07-03 19:39:07Z olamy $
+ * @version $Id: AbstractSourceJarMojo.java 1626353 2014-09-19 22:17:31Z krosenvold $
  * @since 2.0.3
  */
 public abstract class AbstractSourceJarMojo
@@ -190,6 +191,12 @@ public abstract class AbstractSourceJarMojo
     @Parameter( property = "source.skip", defaultValue = "false" )
     private boolean skipSource;
 
+    /**
+     * The Maven session.
+     */
+    @Parameter( defaultValue = "${session}", readonly = true, required = true )
+    private MavenSession session;
+    
     // ----------------------------------------------------------------------
     // Public methods
     // ----------------------------------------------------------------------
@@ -267,7 +274,7 @@ public abstract class AbstractSourceJarMojo
             archiveProjectContent( subProject, archiver.getArchiver() );
         }
 
-        if ( !archiver.getArchiver().getFiles().isEmpty() )
+        if ( archiver.getArchiver().getResources().hasNext() || forceCreation )
         {
 
             if ( useDefaultManifestFile && defaultManifestFile.exists() && archive.getManifestFile() == null )
@@ -285,7 +292,7 @@ public abstract class AbstractSourceJarMojo
                 archive.setAddMavenDescriptor( false );
                 archive.setForced( forceCreation );
 
-                archiver.createArchive( project, archive );
+                archiver.createArchive( session, project, archive );
             }
             catch ( IOException e )
             {
